Constructor for S3 defol class
defol(year, series, gsi, ngsi, defol_status)a tree-level defol object
An n-length integer vector of observation years
An n-length factor or character vector of series names
An n-length numeric vector of growth suppression index, such as
calculated by gsi()
An n-length numeric vector of normalized gsi, such as calculated
by gsi().
An n-length factor or character vector denoting the
defoliation event status of each year. This uses a controlled vocabulary,
see dfoliatR:::make_defol_status for possible values.