This function removes the nonhost growth signal from a host tree-ring series.
gsi(input_series)A data frame with the two input columns (host and nonhost series) and 3 added columns:
The mean/sd adjusted non-host chronology,
The growth suppression index ("gsi") of the host series after subtraction of the adjusted nonhost chronology,
The normalized growth suppression
index ("ngsi") generated by applying scale() to the gsi.
A dplr::rwl object with the host tree series as the
first column and the non-host chronology as the second. Years should be the
row names. This is specifically created by defoliate_trees() and
passed to gsi().
The growth suppression index (GSI) is referred to as the "corrected" series in OUTBREAK. It is calculated as:
$$GSI(i) = H(i) - (NH(i) - mean(NH)) sd(H)/sd(NH)$$
where H and NH are the host and nonhost tree-ring series as standardized
index values; i is the year, and the functions mean() and sd() are
applied to the common period.
gsi() will rarely be run directly by a user. It is called from
defoliate_trees().