Learn R Programming

dfoliatR (version 0.3.0)

obr: Constructor for an obr object.

Description

Constructor for an obr object.

Usage

obr(
  year,
  samp_depth,
  num_defol,
  perc_defol,
  num_max_defol,
  perc_max_defol,
  mean_gsi,
  mean_ngsi,
  outbreak_status
)

Value

An obr object with columns matching the input variables.

Arguments

year

An n-length numeric vector of observed years.

samp_depth

An n-length numeric vector of the number of trees.

num_defol

An n-length numeric vector of the number of trees experiencing defoliation.

perc_defol

An n-length numeric vector of the percent of trees experiencing defoliation.

num_max_defol

An n-length numeric vector of the number of trees experiencing their maximum level of defoliation (i.e., their most extreme negative growth departure).

perc_max_defol

An n-length numeric vector of the percent of trees experiencing their maximum level of defoliation (i.e., their most extreme negative growth departure).

mean_gsi

An n-length numeric vector of the average growth suppression index across all observed trees.

mean_ngsi

An n-length numeric vector of the average normalized (scaled) growth suppression index.

outbreak_status

An n-length factor or character vector that identified whether that year surpasses the designated thresholds for an "outbreak event". Threshold criteria are provided in outbreak().