obr object.Constructor for an obr object.
obr(
year,
samp_depth,
num_defol,
perc_defol,
num_max_defol,
perc_max_defol,
mean_gsi,
mean_ngsi,
outbreak_status
)An obr object with columns matching the input variables.
An n-length numeric vector of observed years.
An n-length numeric vector of the number of trees.
An n-length numeric vector of the number of trees experiencing defoliation.
An n-length numeric vector of the percent of trees experiencing defoliation.
An n-length numeric vector of the number of trees experiencing their maximum level of defoliation (i.e., their most extreme negative growth departure).
An n-length numeric vector of the percent of trees experiencing their maximum level of defoliation (i.e., their most extreme negative growth departure).
An n-length numeric vector of the average growth suppression index across all observed trees.
An n-length numeric vector of the average normalized (scaled) growth suppression index.
An n-length factor or character vector that identified
whether that year surpasses the designated thresholds for an "outbreak
event". Threshold criteria are provided in outbreak().